@@ -1,5 +1,5 @@
 .CV.nnet = function(Input, Target, size=c(2,4,6, 8), decay=c(0.001, 0.01, 0.05, 0.1), nbCV=5, W=NULL){
-  require(pROC, quietly=T)
+#   require(pROC, quietly=T)
 
   Eval = data.frame(matrix(0, ncol=3, nrow=16, dimnames=list(NULL, c("Size", "Decay", "AUC"))))
   Eval[,1] = rep(size,4)
@@ -13,7 +13,7 @@
             nn = nnet(eval(parse(text = paste("Target[Samp$calibration]",
                   paste(.scopeExpSyst(Input[1:10, ,drop=FALSE], "GBM"), collapse = "")))),data=Input[Samp$calibration, ,drop=FALSE],
                   size = x[1], decay = x[2], maxit = 200, trace = FALSE)
-            AUC = as.numeric(auc(roc(Target[Samp$evaluation], predict(nn, Input[Samp$evaluation,,drop=FALSE]))))
+            AUC = as.numeric(pROC::auc(pROC::roc(Target[Samp$evaluation], predict(nn, Input[Samp$evaluation,,drop=FALSE]))))
             return(AUC)
           })
       } else{
@@ -21,7 +21,7 @@
             nn = nnet(eval(parse(text = paste("Target[Samp$calibration]",
                   paste(.scopeExpSyst(Input[1:10, ,drop=FALSE], "GBM"), collapse = "")))),data=Input[Samp$calibration, ,drop=FALSE],
                   weights=W[Samp$calibration], size = x[1], decay = x[2], maxit = 200, trace = FALSE)
-            AUC = as.numeric(auc(roc(Target[Samp$evaluation], predict(nn, Input[Samp$evaluation,,drop=FALSE]))))
+            AUC = as.numeric(pROC::auc(pROC::roc(Target[Samp$evaluation], predict(nn, Input[Samp$evaluation,,drop=FALSE]))))
             return(AUC)
           })
       }
