@@ -75,11 +75,11 @@ setMethod('FilteringTransformation', signature(data='RasterStack'),
   function(data, threshold)
   {
     if(length(threshold) == 1){
-      threshold <- rep(threshold, raster:::nlayers(data))
+      threshold <- rep(threshold, raster::nlayers(data))
     }
-    StkTmp <- raster:::stack()
-    for(i in 1:raster:::nlayers(data)){
-      StkTmp <- raster:::addLayer(StkTmp, FilteringTransformation(raster:::subset(data,i,drop=TRUE), threshold[i]))
+    StkTmp <- raster::stack()
+    for(i in 1:raster::nlayers(data)){
+      StkTmp <- raster::addLayer(StkTmp, FilteringTransformation(raster::subset(data,i,drop=TRUE), threshold[i]))
     }
     names(StkTmp) <- names(data)
     return(StkTmp)
@@ -88,6 +88,6 @@ setMethod('FilteringTransformation', signature(data='RasterStack'),
 setMethod('FilteringTransformation', signature(data='RasterBrick'), 
   function(data, threshold)
   {
-    data <- raster:::stack(data)
+    data <- raster::stack(data)
     return(FilteringTransformation(data, threshold))
   })
\ No newline at end of file
