@@ -20,6 +20,7 @@
   
   m_outdir <- file.path(species.name,'models',modeling.id, paste(RunName,'_MAXENT_outputs',sep=''))
   MWD$m_outdir <- m_outdir
+  MWD$m_outputFile <- file.path(m_outdir,paste(RunName,'_Pred_swd.csv',sep=''))
   
   ## directories creation
   dir.create(m_workdir, showWarnings=FALSE, recursive=TRUE, mode='777')
@@ -54,6 +55,7 @@
   colnames(Pred_swd)  <- c("predict",colnames(Back_swd)[-1])
   write.table(Pred_swd, file=m_predictFile, quote=FALSE, row.names=FALSE, col.names=TRUE, sep=",")
   
+  
   ### USELESS ###
   # dealing with variable importances stuff
 #   if( VarImport > 0){
@@ -167,6 +169,11 @@ setMethod('.Prepare.Maxent.Proj.WorkDir', signature(Data='RasterStack'),
             return(MWD)
           })
 
+setMethod('.Prepare.Maxent.Proj.WorkDir', signature(Data='RasterLayer'),
+          def = function(Data, species.name =".",proj.name=".", silent=FALSE){
+            .Prepare.Maxent.Proj.WorkDir(Data=stack(Data), species.name =species.name ,proj.name=proj.name , silent=silent)
+          })
+
 # .Prepare.Maxent.Proj.WorkDir <- function(Data, xy, proj_name=NULL){
 #   cat('\n\tCreating Maxent Temp Proj Data..')
 #   
