@@ -161,7 +161,9 @@ function(sp, env, nb.repet=1, strategy='random', distMin=0, distMax=NULL, nb.poi
 
   if(inherits(data, 'SpatialPoints')){ return(sum(is.na(data@data))) }
   
-  if(inherits(data, 'Raster')){ return( sum(na.omit(data[]) == -1) )}
+#   if(inherits(data, 'Raster')){ cat("\n\t***") ; return( sum(na.omit(data[]) == -1) )}
+  
+  if(inherits(data, 'Raster')){ return(sum(data[] == -1, na.rm=T)) }
 }
 
 # -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-= #
@@ -215,7 +217,7 @@ setMethod('random.pseudo.abs.selection', signature(env="SpatialPointsDataFrame")
 
 setMethod('random.pseudo.abs.selection', signature(env="RasterStack"),
           function( sp, env, nb.points, nb.repet ){
-            require('raster',quietly=T)
+#             require('raster',quietly=T)
             cat("\n   > random pseudo absences selection")
 
             # 1. Check if NA are present in sp or not to determine which dataset to use
@@ -244,10 +246,9 @@ setMethod('random.pseudo.abs.selection', signature(env="RasterStack"),
             } else {
               cat("\n   > Pseudo absences are selected in explanatory variables")
               # create a mask
-              mask <- raster:::subset(env, 1, drop=TRUE)
-#               mask <- reclassify(mask, c(-Inf,Inf,-1))
-              mask[!is.na(mask[])] <- -1
-              
+              mask <- raster::subset(env, 1, drop=TRUE)
+              mask <- raster::reclassify(mask, c(-Inf,Inf,-1))
+
               # remove presences and true absences from our raster
               mask[cellFromXY(mask,coordinates(sp))] <- NA
               
@@ -259,10 +260,17 @@ setMethod('random.pseudo.abs.selection', signature(env="RasterStack"),
                 cat("\n   > All availables cells have been selected (", nb.points, "pseudo absences selected )")
               }
               
+              
               # select cells into raster
               pa.tab.tmp <- matrix(NA, ncol=nb.repet, nrow=nb.points)
               for( j in 1:ncol(pa.tab.tmp)){
-                pa.tab.tmp[,j] <- sampleRandom(x=mask, size=nb.points, cells=T)[,"cell"]
+                SR <- sampleRandom(x=mask, size=nb.points, cells=T, na.rm=T)[,"cell", drop=T]
+                ## repeat sampling until haing the right number of points
+                ## NOTE: it's a bit tricky way to process becaus some points shoul appe several times
+                while(length(SR)<nb.points){
+                  SR <- c(SR, sampleRandom(x=mask, size=nb.points-length(SR), cells=T, na.rm=T)[,"cell", drop=T])
+                }
+                pa.tab.tmp[,j] <- SR
               }
               
               # puting cells in good format
@@ -275,6 +283,7 @@ setMethod('random.pseudo.abs.selection', signature(env="RasterStack"),
               
               # puting presences, true absences and pseudo absences together
               xy <- rbind(coordinates(sp), xyFromCell(mask, selected.cells))
+              xy <- .add_PA_rownames(xy) 
               sp <- as.numeric(unlist(c(as.vector(sp@data), rep(NA,length(selected.cells))), use.names=FALSE))
               env <- extract(env, xy)
 
@@ -310,7 +319,7 @@ setMethod('user.defined.pseudo.abs.selection', signature(env="SpatialPointsDataF
 
 setMethod('user.defined.pseudo.abs.selection', signature(env="RasterStack"),
           function( sp, env, pa.table ){
-            require('raster',quietly=T)
+#             require('raster',quietly=T)
             cat("\n   > User defined pseudo absences selection")
 
             env <- as.data.frame(extract(env, coordinates(sp), method='bilinear'))
@@ -337,7 +346,7 @@ setMethod('sre.pseudo.abs.selection', signature(env="SpatialPointsDataFrame"),
             mask <- sre(Response = sp, Explanatory = env, NewData = env@data, Quant = quant.SRE)
             
             # removing cells in envelops, presences and absences
-            mask[mask[] == 0] <- NA
+            mask[mask == 0] <- NA
             mask[which(as.vector(sp@data)==1),1] <- 1
             mask[which(as.vector(sp@data)==0),1] <- 0
 
@@ -376,11 +385,11 @@ setMethod('sre.pseudo.abs.selection', signature(env="RasterStack"),
             mask <- sre(Response = sp, Explanatory = env, NewData = env, Quant = quant.SRE) 
             
             # removing cells in envelops, presences and absences
-            mask[mask[]==1] <- NA
+            mask[mask==1] <- NA
             mask[cellFromXY(mask,coordinates(sp)[which(as.vector(sp@data)==1),])] <- NA
             mask[cellFromXY(mask,coordinates(sp)[which(as.vector(sp@data)==0),])] <- NA
             
-            mask <- reclassify(mask, c(-Inf,Inf,-1))
+            mask <- raster::reclassify(mask, c(-Inf,Inf,-1))
             
             # checking of nb candidates
             nb.cells <- .nb.available.pa.cells(mask)
@@ -393,9 +402,15 @@ setMethod('sre.pseudo.abs.selection', signature(env="RasterStack"),
             # select cells into raster
             pa.tab.tmp <- matrix(NA, ncol=nb.repet, nrow=nb.points)
             for( j in 1:ncol(pa.tab.tmp)){
-              pa.tab.tmp[,j] <- sampleRandom(x=mask, size=nb.points, cells=T)[,"cell"]
+              SR <- sampleRandom(x=mask, size=nb.points, cells=T, na.rm=T)[,"cell", drop=T]
+              ## repeat sampling until haing the right number of points
+              ## NOTE: it's a bit tricky way to process becaus some points shoul appe several times
+              while(length(SR)<nb.points){
+                SR <- c(SR, sampleRandom(x=mask, size=nb.points-length(SR), cells=T, na.rm=T)[,"cell", drop=T])
+              }
+              pa.tab.tmp[,j] <- SR
             }
-            
+
             # puting cells in good format
             selected.cells <- sort(unique(as.vector(pa.tab.tmp)))
             pa.tab <- matrix(FALSE, ncol = nb.repet, nrow = length(selected.cells))
@@ -406,6 +421,7 @@ setMethod('sre.pseudo.abs.selection', signature(env="RasterStack"),
             
             # puting presences, true absences and pseudo absences together
             xy <- rbind(coordinates(sp)[which(!is.na(as.vector(sp@data))),], xyFromCell(mask, selected.cells))
+            xy <- .add_PA_rownames(xy) 
             sp <- as.numeric(unlist(c(na.omit(as.vector(sp@data)), rep(NA,length(selected.cells))), use.names=FALSE))
             env <- extract(env, xy)
           
@@ -475,14 +491,14 @@ setMethod('disk.pseudo.abs.selection', signature(env="RasterStack"),
               cat("\n   > Pseudo absences are selected in explanatory variables")
               
               # create a mask
-              dist.mask <- raster:::subset(env,1, drop=TRUE)
+              dist.mask <- raster::subset(env,1, drop=TRUE)
               dist.mask[] <- NA
               
               pres.xy <- coordinates(sp[which(sp@data[,1]==1),])
               dist.mask[cellFromXY(dist.mask,pres.xy)] <- 1
               
-              dist.mask <- distance(dist.mask)
-              dist.mask <- mask(dist.mask, raster:::subset(env,1, drop=TRUE))
+              dist.mask <- raster::distance(dist.mask)
+              dist.mask <- mask(dist.mask, raster::subset(env,1, drop=TRUE))
               
               if(is.null(distMax)) distMax <- Inf
               mask <- reclassify(dist.mask, c(-Inf,distMin,NA ,distMin, distMax,-1, distMax,Inf,NA))
@@ -514,6 +530,7 @@ setMethod('disk.pseudo.abs.selection', signature(env="RasterStack"),
               
               # puting presences, true absences and pseudo absences together
               xy <- rbind(coordinates(sp), xyFromCell(mask, selected.cells))
+              xy <- .add_PA_rownames(xy) 
               sp <- as.numeric(unlist(c(as.vector(sp@data), rep(NA,length(selected.cells))), use.names=FALSE))
               env <- extract(env, xy)
 
@@ -528,6 +545,19 @@ setMethod('disk.pseudo.abs.selection', signature(env="RasterStack"),
             } 
           })
 
+# -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-= #  
+# automaticaly add rownames to a data.frame
+.add_PA_rownames <- function(xy){
+  rn <- row.names(xy)
+  missing_rn <- which(rn == "")
+  if(length(missing_rn)){
+    rn[missing_rn] <- paste("pa", 1:length(missing_rn), sep="")
+  }
+  rownames(xy) <- rn
+  return(xy)
+}
+# -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-= #  
+
 # setMethod('disk.pseudo.abs.selection', signature(env="RasterStack"),
 #           function(sp, env, distMin, distMax, nb.points, nb.repet){
 #             cat("\n   > Disk pseudo absences selection")
@@ -542,7 +572,7 @@ setMethod('disk.pseudo.abs.selection', signature(env="RasterStack"),
 #               cat("\n   > Pseudo absences are selected in explanatory variables")
 #               
 #               # create a mask
-#               mask <- maskInside <- maskOutside <- reclassify(raster:::subset(env,1), c(-Inf,Inf,0))
+#               mask <- maskInside <- maskOutside <- reclassify(raster::subset(env,1), c(-Inf,Inf,0))
 #               pres.xy <- coordinates(sp[which(sp@data[,1]==1),])
 #               
 #               # to convert longitudinal degrees into metters
